define(
//begin v1.x content
{
	"HKD_displayName": "hongkonský dolár",
	"CNY_displayName": "čínsky jüan",
	"JPY_displayName": "japonský jen",
	"JPY_symbol": "JPY",
	"USD_displayName": "americký dolár",
	"CAD_symbol": "CAD",
	"GBP_displayName": "britská libra",
	"CHF_displayName": "švajčiarsky frank",
	"CNY_symbol": "CNY",
	"EUR_displayName": "euro",
	"GBP_symbol": "GBP",
	"CAD_displayName": "kanadský dolár",
	"USD_symbol": "USD",
	"EUR_symbol": "€",
	"AUD_displayName": "austrálsky dolár",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HKD",
	"AUD_symbol": "AUD"
}
//end v1.x content
);